==> beagle-0.0.12.tar.bz2: beagle-0.0.12/beagled/SanityCheckTool.cs <==
//
// SanityCheckTool.cs
// Copyright (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//


using System;
using System.IO;

using Beagle.Util;
using Beagle.Daemon;
using Beagle.Daemon.FileSystemQueryable;

class SanityCheckTool {

	static void Main (string [] args)
	{
		Logger.DefaultEcho = true;
		Logger.DefaultLevel = LogLevel.Debug;

		string fs_dir = Path.Combine (PathFinder.StorageDir, "FileSystemIndex");

		FileSystemModel model = new FileSystemModel (fs_dir, null, null);

		// FIXME: Shouldn't be hard-wired
		model.AddRoot (PathFinder.HomeDir);

		SanityCheck.CheckDirectory (PathFinder.HomeDir, null, model);
	}
}

==> beagle-0.2.7.tar.bz2: beagle-0.2.7/beagled/SanityCheckTool.cs <==
//
// SanityCheckTool.cs
// Copyright (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//


using System;
using System.IO;

using Beagle.Util;
using Beagle.Daemon;
using Beagle.Daemon.FileSystemQueryable;

class SanityCheckTool {

	static void Main (string [] args)
	{
#if false
		Logger.DefaultEcho = true;
		Logger.DefaultLevel = LogLevel.Debug;

		string fs_dir = Path.Combine (PathFinder.IndexDir, "FileSystemIndex");

		FileSystemModel model = new FileSystemModel (fs_dir, null, null);

		// FIXME: Shouldn't be hard-wired
		model.AddRoot (PathFinder.HomeDir);

		SanityCheck.CheckDirectory (PathFinder.HomeDir, null, model);
#endif
	}
}
